# Wlyrics
Created by W4lk3r with Python3
# Get Lyrics

```python
from Wlyrics.lyrics import ly

ly(singer_name, song_name)

```

# Example Code


```python
from Wlyrics.lyrics import ly

ly("Imagine Dragons", "Whatever it takes")

```

